==> openGion7.2.6.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE81S.sql <==
/****************************************************************************/
/* GE81 ( 新着情報ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE81 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      varchar           (   20 )      DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , CDDEG        varchar           (    1 )                                      /*  30 重要度       */
 , TITLE        varchar           (  300 )                                      /*  40 ﾀｲﾄﾙ         */
 , NAIYO        varchar           ( 4000 )                                      /*  50 内容         */
 , DYSTRD       varchar           (    8 )                  NOT NULL            /*  60 掲載開始日   */
 , DYENDD       varchar           (    8 )                  NOT NULL            /*  70 掲載終了日   */
 , BUSHOD       varchar           (  100 )                                      /*  80 掲載部署     */
 , MAND         varchar           (   50 )                                      /*  90 掲載者       */
 , TEL          varchar           (   20 )                                      /* 100 電話番号     */
 , MAILAD       varchar           (  100 )                                      /* 110 ﾒｰﾙｱﾄﾞﾚｽ     */
 , FILE1        varchar           (  200 )                                      /* 120 ﾌｧｲﾙ1        */
 , FILE2        varchar           (  200 )                                      /* 130 ﾌｧｲﾙ2        */
 , FILE3        varchar           (  200 )                                      /* 140 ﾌｧｲﾙ3        */
 , FILEPATH     varchar           (  200 )                                      /* 150 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          varchar           (  200 )                                      /* 160 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE81S.sql <==
/****************************************************************************/
/* GE81 ( 新着情報ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE81 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , SYSCODE      varchar           (   20 )      DEFAULT '*' NOT NULL            /*  20 ｼｽﾃﾑｺｰﾄﾞ     */
 , CDDEG        varchar           (    1 )                                      /*  30 重要度       */
 , TITLE        varchar           (  300 )                                      /*  40 ﾀｲﾄﾙ         */
 , NAIYO        varchar           ( 4000 )                                      /*  50 内容         */
 , DYSTRD       varchar           (    8 )                  NOT NULL            /*  60 掲載開始日   */
 , DYENDD       varchar           (    8 )                  NOT NULL            /*  70 掲載終了日   */
 , BUSHOD       varchar           (  100 )                                      /*  80 掲載部署     */
 , MAND         varchar           (   50 )                                      /*  90 掲載者       */
 , TEL          varchar           (   20 )                                      /* 100 電話番号     */
 , MAILAD       varchar           (  100 )                                      /* 110 ﾒｰﾙｱﾄﾞﾚｽ     */
 , FILE1        varchar           (  200 )                                      /* 120 ﾌｧｲﾙ1        */
 , FILE2        varchar           (  200 )                                      /* 130 ﾌｧｲﾙ2        */
 , FILE3        varchar           (  200 )                                      /* 140 ﾌｧｲﾙ3        */
 , FILEPATH     varchar           (  200 )                                      /* 150 ﾌｧｲﾙﾊﾟｽ      */
 , TAG          varchar           (  200 )                                      /* 160 ﾀｸﾞｷｰﾜｰﾄﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
